@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp ();
 use Scalar::Util qw(looks_like_number);
@@ -32,12 +32,25 @@ sub new {
         Carp::croak("'header' param should be ArrayRef");
     }
 
+    my $alignment = delete $args{alignment};
+    if (defined $alignment) {
+        unless ($alignment eq 'left' || $alignment eq 'right') {
+            Carp::croak("'alignment' param should be 'left' or 'right'");
+        }
+        if ($alignment eq 'left') {
+            $alignment = ALIGN_LEFT;
+        } else {
+            $alignment = ALIGN_RIGHT;
+        }
+    }
+
     my $ansi_color = delete $args{ansi_color} || 0;
     my $self = bless {
         header     => [],
         rows       => [],
         border     => 1,
         ansi_color => $ansi_color,
+        alignment  => $alignment,
         %args,
     }, $class;
 
@@ -81,7 +94,7 @@ sub _divide_multiline {
     for my $i (0..($longest-1)) {
         my @cells;
         for my $j (0..($self->{width}-1)) {
-            $alignments[$j] ||= _decide_alignment($each_lines[$j]->[$i]);
+            $alignments[$j] ||= $self->_decide_alignment($each_lines[$j]->[$i]);
             push @cells, Text::UnicodeTable::Simple::Cell->new(
                 text      => $each_lines[$j]->[$i],
                 alignment => $alignments[$j],
@@ -95,7 +108,9 @@ sub _divide_multiline {
 }
 
 sub _decide_alignment {
-    return looks_like_number($_[0]) ? ALIGN_RIGHT : ALIGN_LEFT;
+    my ($self, $str) = @_;
+    return $self->{alignment} if $self->{alignment};
+    return looks_like_number($str) ? ALIGN_RIGHT : ALIGN_LEFT;
 }
 
 sub _adjust_cols {
@@ -421,6 +436,11 @@ Table has no border if C<border> is False.
 
 Ignore ANSI color escape sequence
 
+=item alignment :Int = 'left' or 'right'
+
+Alignment for each columns. Every columns are aligned by this if you
+specify this parameter.
+
 =back
 
 =head3 set_header() [alias: addCols ]
